| dbplot_bar | R Documentation |
Uses dplyr operations to aggregate data and then 'ggplot2' to create the plot. Because of this approach, the calculations automatically run inside the database if 'data' has a database or sparklyr connection. The 'class()' of such tables in R are: tbl_sql, tbl_dbi, tbl_spark
dbplot_bar(data, x, ..., y = n())
data |
A table (tbl) |
x |
A discrete variable |
... |
A set of named or unnamed aggregations |
y |
The aggregation formula. Defaults to count (n) |
A ggplot object with a bar plot. If multiple aggregations are provided, returns a list of ggplot objects, one for each aggregation.
dbplot_line ,
dbplot_histogram, dbplot_raster
## Not run:
library(DBI)
library(dplyr)
library(ggplot2)
con <- dbConnect(duckdb::duckdb(), ":memory:")
db_mtcars <- copy_to(con, mtcars, "mtcars")
# Returns a plot of the row count per am
db_mtcars |>
dbplot_bar(am)
# Returns a plot of the average mpg per am
db_mtcars |>
dbplot_bar(am, mean(mpg))
# Returns the average and sum of mpg per am
db_mtcars |>
dbplot_bar(am, avg_mpg = mean(mpg), sum_mpg = sum(mpg))
dbDisconnect(con)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.