Uses dplyr operations to aggregate data and then `ggplot2` to create the boxplot. Because of this approach, the calculations automatically run inside the database if `data` has a database or sparklyr connection. The `class()` of such tables in R are: tbl_sql, tbl_dbi, tbl_spark

Requires database support for percentile/quantile functions. See db_compute_boxplot for supported database backends.

dbplot_boxplot(data, x, var, coef = 1.5)

Arguments

data

A table (tbl)

x

A discrete variable in which to group the boxplots

var

A continuous variable

coef

Length of the whiskers as multiple of IQR. Defaults to 1.5

Examples

mtcars |>
  dbplot_boxplot(am, mpg)