Uses dplyr operations to aggregate data and then `ggplot2` to create the boxplot. Because of this approach, the calculations automatically run inside the database if `data` has a database or sparklyr connection. The `class()` of such tables in R are: tbl_sql, tbl_dbi, tbl_spark
Requires database support for percentile/quantile functions.
See db_compute_boxplot for supported database backends.
dbplot_boxplot(data, x, var, coef = 1.5)mtcars |>
dbplot_boxplot(am, mpg)