| dbplot_histogram | R Documentation |
Uses dplyr operations to aggregate data and then 'ggplot2' to create the histogram. Because of this approach, the calculations automatically run inside the database if 'data' has a database or sparklyr connection. The 'class()' of such tables in R are: tbl_sql, tbl_dbi, tbl_spark
dbplot_histogram(data, x, bins = 30, binwidth = NULL)
data |
A table (tbl) |
x |
A continuous variable |
bins |
Number of bins. Defaults to 30. |
binwidth |
Fixed width for each bin, in the same units as the data. Overrides bins when specified |
A ggplot object displaying a histogram of the specified variable.
dbplot_bar, dbplot_line ,
dbplot_raster
## Not run:
library(DBI)
library(dplyr)
library(ggplot2)
con <- dbConnect(duckdb::duckdb(), ":memory:")
db_mtcars <- copy_to(con, mtcars, "mtcars")
# A ggplot histogram with 30 bins
db_mtcars |>
dbplot_histogram(mpg)
# A ggplot histogram with bins of size 10
db_mtcars |>
dbplot_histogram(mpg, binwidth = 10)
dbDisconnect(con)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.